local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

require("lazy").setup({
  {
    "EdenEast/nightfox.nvim",
    lazy=false,
    priority=1000
  },
  {"salkin-mada/openscad.nvim", event="BufRead"},
  {"ChiliConSql/neovim-stylus", event="BufRead"},
  {"digitaltoad/vim-pug", event="BufRead"},
  {"pirmd/gemini.vim", event="BufRead"},
  {"dpelle/vim-Grammalecte"},
  {"vigoux/LanguageTool.nvim"},
  {"chaimleib/vim-renpy", event="BufRead"}
})

vim.opt.clipboard = 'unnamedplus'

vim.opt.tabstop = 4
vim.opt.softtabstop = 4
vim.opt.shiftwidth = 4
vim.opt.expandtab = true

vim.opt.number = false
vim.opt.cursorline = true
vim.opt.splitbelow = true
vim.opt.splitright = true
vim.opt.termguicolors = true
vim.opt.showmode = false
vim.opt.textwidth=78
vim.opt.colorcolumn = "29,30,71,72,79,80,119,120,139,140"

vim.opt.incsearch = true
vim.opt.hlsearch = false
vim.opt.ignorecase = true
vim.opt.smartcase = true

vim.opt.fdm = 'indent'
vim.opt.listchars = {eol = '¶', tab = '⁝‧' , extends = '␐', precedes= '␑', trail = '˽', nbsp = '⎵' }
vim.opt.list = true

vim.opt.spelllang = 'fr'
vim.g.grammalecte_cli_py = '/usr/bin/grammalecte-cli'
vim.g.languagetool_jar = '~/.bin/languagetool-commandline.jar'

opts = {noremap=true, silent=true}
vim.keymap.set('n', '<tab>', "gt", opts)
vim.keymap.set('n', '<S-tab>', "gT", opts)
vim.keymap.set('v', 'gl', ":'<,'>!lou_translate en-us-brf.dis,fr-bfu-comp6.utb,braille-patterns.cti<CR>", opts)
vim.keymap.set('v', 'gL', ":'<,'>!lou_translate --backward en-us-brf.dis,fr-bfu-comp6.utb,braille-patterns.cti<CR>", opts)

vim.cmd 'colorscheme nightfox'
vim.transparent_window = true

vim.cmd 'highlight Normal ctermbg=none guibg=none'
